### Name: VGAM-package
### Title: Vector Generalized Linear and Additive Models
### Aliases: VGAM-package VGAM
### Keywords: package models regression

### ** Examples

# Example 1
# Fit the proportional odds model, p.179, in McCullagh and Nelder (1989)
pneumo = transform(pneumo, let=log(exposure.time))
(fit = vglm(cbind(normal, mild, severe) ~ let,
            cumulative(parallel=TRUE, reverse=TRUE), pneumo))
fit@y   # Sample proportions
weights(fit, type="prior")   # Number of observations
coef(fit, matrix=TRUE)
constraints(fit)   # Constraint matrices

# Example 2
# Zero-inflated Poisson model
x = runif(n <- 2000)
phi = logit(-0.5 + 1*x, inverse=TRUE)
lambda = loge(0.5 + 2*x, inverse=TRUE)
y = rzipois(n, lambda, phi)
table(y)
fit = vglm(y ~ x, zipoisson, trace=TRUE)
coef(fit, matrix=TRUE)  # These should agree with the above values

# Example 3
# Fit a two species GAM simultaneously
fit2 = vgam(cbind(agaaus, kniexc) ~ s(altitude, df=c(2,3)),
            binomialff(mv=TRUE), hunua)
coef(fit2, mat=TRUE)   # Not really interpretable
## Not run: 
##D plot(fit2, se=TRUE, overlay=TRUE, lcol=1:2, scol=1:2)
##D 
##D o = with(hunua, order(altitude))
##D with(hunua,  matplot(altitude[o], fitted(fit2)[o,], type="l", lwd=2,
##D      xlab="Altitude (m)", ylab="Probability of presence", las=1,
##D      main="Two plant species' response curves", ylim=c(0,.8)))
##D with(hunua, rug(altitude))
## End(Not run)

# Example 4
# LMS quantile regression
fit = vgam(BMI ~ s(age, df=c(4,2)), lms.bcn(zero=1), dat=bminz, trac=TRUE)
head(predict(fit))
head(fitted(fit))
head(bminz) # Person 1 is near the lower quartile among people his age
head(cdf(fit))

## Not run: 
##D # Quantile plot
##D par(mfrow=c(1,1), bty="l", mar=c(5,4,4,3)+0.1, xpd=TRUE)
##D qtplot(fit, percentiles=c(5,50,90,99), main="Quantiles",
##D        xlim=c(15,90), las=1, ylab="BMI", lwd=2, lcol=4)
##D 
##D # Density plot
##D ygrid = seq(15, 43, len=100)  # BMI ranges
##D par(mfrow=c(1,1), lwd=2)
##D a = deplot(fit, x0=20, y=ygrid, xlab="BMI", col="black",
##D     main="Density functions at Age = 20 (black), 42 (red) and 55 (blue)")
##D a
##D a = deplot(fit, x0=42, y=ygrid, add=TRUE, llty=2, col="red")
##D a = deplot(fit, x0=55, y=ygrid, add=TRUE, llty=4, col="blue", Attach=TRUE)
##D a@post$deplot  # Contains density function values
## End(Not run)

# Example 5
# GEV distribution for extremes
(fit = vglm(maxtemp ~ 1, egev, data=oxtemp, trace=TRUE))
head(fitted(fit))
coef(fit, mat=TRUE)
Coef(fit)
vcov(fit)
vcov(fit, untransform=TRUE)
sqrt(diag(vcov(fit)))   # Approximate standard errors
## Not run:  rlplot(fit) 



