### Name: amlnormal
### Title: Asymmetric Least Squares Quantile Regression
### Aliases: amlnormal
### Keywords: models regression

### ** Examples

# Example 1
o = with(bminz, order(age))
bminz = bminz[o,]  # Sort by age
(fit = vglm(BMI ~ bs(age), fam=amlnormal(w.als=0.1), data=bminz))
fit@extra  # Gives the w value and the percentile
coef(fit)
coef(fit, matrix=TRUE)

## Not run: 
##D # Quantile plot
##D with(bminz, plot(age, BMI, col="blue", main=
##D      paste(round(fit@extra$percentile, dig=1),
##D            "expectile-percentile curve")))
##D with(bminz, lines(age, c(fitted(fit)), col="black"))
## End(Not run)


# Example 2
# Find the w values that give the 25, 50 and 75 percentiles
findw = function(w, percentile=50) {
    fit2 = vglm(BMI ~ bs(age), fam=amlnormal(w=w), data=bminz)
    fit2@extra$percentile - percentile
}
## Not run: 
##D # Quantile plot
##D with(bminz, plot(age, BMI, col="blue", las=1, main=
##D      "25, 50 and 75 expectile-percentile curves"))
## End(Not run)
for(myp in c(25,50,75)) {
# Note: uniroot() can only find one root at a time
    bestw = uniroot(f=findw, interval=c(1/10^4, 10^4), percentile=myp)
    fit2 = vglm(BMI ~ bs(age), fam=amlnormal(w=bestw$root), data=bminz)
## Not run: 
##D     with(bminz, lines(age, c(fitted(fit2)), col="red"))
## End(Not run)
}


# Example 3; this is Example 1 but with smoothing splines and
# a vector w and a parallelism assumption.
o = with(bminz, order(age))
bminz = bminz[o,]  # Sort by age
fit3 = vgam(BMI ~ s(age, df=4), fam=amlnormal(w=c(.1,1,10), parallel=TRUE),
            data=bminz, trac=TRUE)
fit3@extra # The w values, percentiles and weighted deviances

# The linear components of the fit; not for human consumption:
coef(fit3, matrix=TRUE)

## Not run: 
##D # Quantile plot
##D with(bminz, plot(age, BMI, col="blue", main=
##D      paste(paste(round(fit3@extra$percentile, dig=1), collapse=", "),
##D            "expectile-percentile curves")))
##D with(bminz, matlines(age, fitted(fit3), col=1:fit3@extra$M, lwd=2))
##D with(bminz, lines(age, c(fitted(fit )), col="black")) # For comparison
## End(Not run)



