### Name: fsqrt
### Title: Folded Square Root Link Function
### Aliases: fsqrt
### Keywords: math models regression

### ** Examples

p = seq(0.01, 0.99, by=0.01)
fsqrt(p)
max(abs(fsqrt(fsqrt(p), inverse=TRUE) - p)) # Should be 0

p = c(seq(-0.02, 0.02, by=0.01), seq(0.97, 1.02, by=0.01))
fsqrt(p)  # Has NAs

## Not run: 
##D p = seq(0.01, 0.99, by=0.01)
##D par(mfrow=c(2,2))
##D y = seq(-4, 4, length=100)
##D for(d in 0:1) {
##D     matplot(p, cbind(logit(p, deriv=d), fsqrt(p, deriv=d)),
##D             type="n", col="purple", ylab="transformation",
##D             lwd=2, las=1,
##D             main=if(d==0) "Some probability link functions"
##D             else "First derivative")
##D     lines(p, logit(p, deriv=d), col="limegreen", lwd=2)
##D     lines(p, probit(p, deriv=d), col="purple", lwd=2)
##D     lines(p, cloglog(p, deriv=d), col="chocolate", lwd=2)
##D     lines(p, fsqrt(p, deriv=d), col="tan", lwd=2)
##D     if(d==0) {
##D         abline(v=0.5, h=0, lty="dashed")
##D         legend(0, 4.5, c("logit", "probit", "cloglog", "fsqrt"),
##D                col=c("limegreen","purple","chocolate", "tan"), lwd=2)
##D     } else
##D         abline(v=0.5, lty="dashed")
##D }
##D 
##D for(d in 0) {
##D     matplot(y, cbind(logit(y, deriv=d, inverse=TRUE),
##D                      fsqrt(y, deriv=d, inverse=TRUE)),
##D             type="n", col="purple", xlab="transformation", ylab="p",
##D             lwd=2, las=1,
##D             main=if(d==0) "Some inverse probability link functions"
##D             else "First derivative")
##D     lines(y, logit(y, deriv=d, inverse=TRUE), col="limegreen", lwd=2)
##D     lines(y, probit(y, deriv=d, inverse=TRUE), col="purple", lwd=2)
##D     lines(y, cloglog(y, deriv=d, inverse=TRUE), col="chocolate", lwd=2)
##D     lines(y, fsqrt(y, deriv=d, inverse=TRUE), col="tan", lwd=2)
##D     if(d==0) {
##D         abline(h=0.5, v=0, lty="dashed")
##D         legend(-4, 1, c("logit", "probit", "cloglog", "fsqrt"),
##D                col=c("limegreen","purple","chocolate", "tan"), lwd=2)
##D     }
##D }
## End(Not run)

# This is lucky to converge
earg = list(min=0, max=1, mux=5)
fit.h = vglm(agaaus ~ bs(altitude),
             fam= binomialff(link="fsqrt", earg=earg),
             data=hunua, trace=TRUE, crit="d")
## Not run: 
##D plotvgam(fit.h, se=TRUE, lcol="red", scol="red",
##D          main="Red is Hunua, Blue is Waitakere")
## End(Not run)
head(predict(fit.h, hunua, type="response"))

## Not run: 
##D # The following fails.
##D pneumo = transform(pneumo, let=log(exposure.time))
##D earg = list(min=0, max=1, mux=10)
##D fit = vglm(cbind(normal, mild, severe) ~ let,
##D            cumulative(link="fsqrt", earg=earg, par=TRUE, rev=TRUE),
##D            data = pneumo, trace=TRUE, maxit=200)
## End(Not run)



