### Name: mbinomial
### Title: The Matched Binomial Distribution Family Function
### Aliases: mbinomial
### Keywords: models regression

### ** Examples

## Not run: 
##D # Cf. Hastie and Tibshirani (1990) p.209. The variable n must be even.
##D # Here, the intercept for each matched set accounts for x3 which is
##D # the confounder or matching variable.
##D n = 700 # Requires a big machine with lots of memory. Expensive wrt time
##D n = 100 # This requires a reasonably big machine.
##D mydat = data.frame(x2 = rnorm(n), x3 = rep(rnorm(n/2), each=2))
##D xmat = with(mydat, cbind(x2,x3))
##D mydat = transform(mydat, eta = -0.1 + 0.2 * x2 + 0.3 * x3)
##D etamat = with(mydat, matrix(eta, n/2, 2))
##D condmu = exp(etamat[,1]) / (exp(etamat[,1]) + exp(etamat[,2]))
##D y1 = ifelse(runif(n/2) < condmu, 1, 0)
##D y = cbind(y1, 1-y1)
##D mydat = transform(mydat, y = c(y1, 1-y1),
##D                          ID = factor(c(row(etamat))))
##D fit = vglm(y ~ 1 + ID + x2, trace=TRUE,
##D            fam = mbinomial(mvar = ~ ID - 1), data=mydat)
##D dimnames(coef(fit, mat=TRUE))
##D coef(fit, mat=TRUE)
##D summary(fit)
##D head(fitted(fit))
##D objsizemb = function(object) round(object.size(object) / 2^20, dig=2)
##D objsizemb(fit) # in Mb
##D 
##D VLMX = model.matrix(fit, type="vlm")  # The big model matrix
##D dim(VLMX)
##D objsizemb(VLMX) # in Mb
##D rm(VLMX)
## End(Not run)



