### Name: mix2poisson
### Title: Mixture of Two Poisson Distributions
### Aliases: mix2poisson
### Keywords: models regression

### ** Examples

# Example 1: simulated data
n = 1000
mu1 = exp(2.5) # also known as lambda1
mu2 = exp(3)
(phi = logit(-0.5, inverse=TRUE))
y = ifelse(runif(n) < phi, rpois(n, mu1), rpois(n, mu2))
fit = vglm(y ~ 1, mix2poisson)
coef(fit, matrix=TRUE)

# Compare the results with the truth
round(rbind('Estimated'=Coef(fit), 'Truth'=c(phi, mu1, mu2)), dig=2)

## Not run: 
##D # Plot the results
##D ty = table(y)
##D plot(names(ty), ty, type="h", main="Red=estimate, blue=truth",
##D      ylab="Frequency", xlab="y")
##D abline(v=Coef(fit)[-1], lty=2, col="red", lwd=2)
##D abline(v=c(mu1, mu2), lty=2, col="blue", lwd=2)
## End(Not run)

# Example 2: London Times data (Lange, 1997, p.31)
deaths = 0:9
freq = c(162, 267, 271, 185, 111, 61, 27, 8, 3, 1)
y = rep(deaths, freq)

# Usually this does not work well unless nsimEIM is large
fit = vglm(deaths ~ 1, weight = freq,
           mix2poisson(iphi=0.3, il1=1, il2=2.5, nsimEIM=5000))

# This works better in general
fit = vglm(y ~ 1, mix2poisson(iphi=0.3, il1=1, il2=2.5))

coef(fit, matrix=TRUE)
Coef(fit)



