### Name: vglm
### Title: Fitting Vector Generalized Linear Models
### Aliases: vglm
### Keywords: models regression

### ** Examples

# Example 1. Dobson (1990) Page 93: Randomized Controlled Trial :
counts = c(18,17,15,20,10,20,25,13,12)
outcome = gl(3,1,9)
treatment = gl(3,3)
print(d.AD <- data.frame(treatment, outcome, counts))
vglm.D93 = vglm(counts ~ outcome + treatment, family=poissonff)
summary(vglm.D93)

# Example 2. Multinomial logit model
pneumo = transform(pneumo, let=log(exposure.time))
vglm(cbind(normal, mild, severe) ~ let, multinomial, pneumo)

# Example 3. Proportional odds model
fit3 = vglm(cbind(normal,mild,severe) ~ let, trace=TRUE,
            cumulative(parallel=TRUE, reverse=TRUE), pneumo)
coef(fit3, matrix=TRUE) 
constraints(fit3)
model.matrix(fit3, type="lm") # LM model matrix
model.matrix(fit3)            # Larger VGLM (or VLM) model matrix

# Example 4. Bivariate logistic model 
fit4 = vglm(cbind(nBnW, nBW, BnW, BW) ~ age, binom2.or, coalminers)
coef(fit4, matrix=TRUE)
fit4@y  # Response are proportions
weights(fit4, type="prior")

# Example 5. The use of the xij argument (simple case).
# The constraint matrix for 'op' has one column.
nn = 1000
eyesdat = round(data.frame(lop = runif(nn),
                           rop = runif(nn),
                            op = runif(nn)), dig=2)
eyesdat = transform(eyesdat, eta1 = -1+2*lop,
                             eta2 = -1+2*lop)
eyesdat = transform(eyesdat,
                    leye = rbinom(nn, size=1, prob=logit(eta1, inv=TRUE)),
                    reye = rbinom(nn, size=1, prob=logit(eta2, inv=TRUE)))
fit5 = vglm(cbind(leye,reye) ~ op,
            binom2.or(exchangeable=TRUE, zero=3),
            data=eyesdat, trace=TRUE,
            xij = list(op ~ lop + rop + fill(lop)),
            form2 = ~  op + lop + rop + fill(lop))
coef(fit5)
coef(fit5, matrix=TRUE)




